using System;
using System.Data;
using System.Configuration;
using System.Web;
using System.Web.Security;
using System.Web.UI;
using System.Web.UI.WebControls;
using System.Web.UI.WebControls.WebParts;
using System.Web.UI.HtmlControls;
using System.Collections.Generic;
using System.Transactions;
using System.Text;

namespace XZ.Logistics.WebShop
{
    public class Order : WebShopBase
    {
        private int _statusId = 0;
        public int StatusId
        {
            get { return _statusId; }
            set { _statusId = value; }
        }

        private string _statusTitle = "";
        public string StatusTitle
        {
            get { return _statusTitle; }
            private set { _statusTitle = value; }
        }

        private OrderStatus _status = null;
        public OrderStatus Status
        {
            get
            {
                if (_status == null)
                    _status = OrderStatus.GetOrderStatusById(this.StatusId);
                return _status;
            }
        }

        private string _shippingMethod = "";
        public string ShippingMethod
        {
            get { return _shippingMethod; }
            private set { _shippingMethod = value; }
        }

        private decimal _subTotal = 0.0m;
        public decimal SubTotal
        {
            get { return _subTotal; }
            private set { _subTotal = value; }
        }

        private decimal _shipping = 0.0m;
        public decimal Shipping
        {
            get { return _shipping; }
            private set { _shipping = value; }
        }

        private string _shippingFirstName = "";
        public string ShippingFirstName
        {
            get { return _shippingFirstName; }
            private set { _shippingFirstName = value; }
        }

        private string _shippingLastName = "";
        public string ShippingLastName
        {
            get { return _shippingLastName; }
            private set { _shippingLastName = value; }
        }

        private string _shippingStreet = "";
        public string ShippingStreet
        {
            get { return _shippingStreet; }
            private set { _shippingStreet = value; }
        }

        private string _shippingPostalCode = "";
        public string ShippingPostalCode
        {
            get { return _shippingPostalCode; }
            private set { _shippingPostalCode = value; }
        }

        private string _shippingCity = "";
        public string ShippingCity
        {
            get { return _shippingCity; }
            private set { _shippingCity = value; }
        }

        private string _shippingState = "";
        public string ShippingState
        {
            get { return _shippingState; }
            private set { _shippingState = value; }
        }

        private string _shippingCountry = "";
        public string ShippingCountry
        {
            get { return _shippingCountry; }
            private set { _shippingCountry = value; }
        }

        private string _customerEmail = "";
        public string CustomerEmail
        {
            get { return _customerEmail; }
            private set { _customerEmail = value; }
        }

        private string _customerPhone = "";
        public string CustomerPhone
        {
            get { return _customerPhone; }
            private set { _customerPhone = value; }
        }

        private string _customerFax = "";
        public string CustomerFax
        {
            get { return _customerFax; }
            private set { _customerFax = value; }
        }

        private string _transactionId = "";
        public string TransactionId
        {
            get { return _transactionId; }
            set { _transactionId = value; }
        }

        private DateTime _shippedDate = DateTime.MinValue;
        public DateTime ShippedDate
        {
            get { return _shippedDate; }
            set { _shippedDate = value; }
        }

        private string _trackingId = "";
        public string TrackingId
        {
            get { return _trackingId; }
            set { _trackingId = value; }
        }

        private List<OrderItem> _items = null;
        public List<OrderItem> Items
        {
            get { return _items; }
            private set { _items = value; }
        }

        public Order(Guid id, DateTime addedDate, string addedBy,
         int statusId, string statusTitle, string shippingMethod, decimal subTotal, decimal shipping,
         string shippingFirstName, string shippingLastName, string shippingStreet,
         string shippingPostalCode, string shippingCity, string shippingState,
         string shippingCountry, string customerEmail, string customerPhone, string customerFax,
         DateTime shippedDate, string transactionID, string trackingID, List<OrderItem> items)
        {
            this.Id = id;
            this.AddedDate = addedDate;
            this.AddedBy = addedBy;
            this.StatusId = statusId;
            this.StatusTitle = statusTitle;
            this.ShippingMethod = shippingMethod;
            this.SubTotal = subTotal;
            this.Shipping = shipping;
            this.ShippingFirstName = shippingFirstName;
            this.ShippingLastName = shippingLastName;
            this.ShippingStreet = shippingStreet;
            this.ShippingPostalCode = shippingPostalCode;
            this.ShippingCity = shippingCity;
            this.ShippingState = shippingState;
            this.ShippingCountry = shippingCountry;
            this.CustomerEmail = customerEmail;
            this.CustomerPhone = customerPhone;
            this.CustomerFax = customerFax;
            this.ShippedDate = shippedDate;
            this.TransactionId = transactionID;
            this.TrackingId = trackingID;
            this.Items = items;
        }

        public bool Delete()
        {
            bool success = Order.DeleteOrder(this.Id);
            if (success)
                this.Id = Guid.Empty;
            return success;
        }

        public bool Update()
        {
            return Order.UpdateOrder(this.Id, this.StatusId, this.ShippedDate, this.TransactionId, this.TrackingId);
        }

        public string GetPayPalPaymentUrl()
        {
            string serverUrl = (Settings.SandboxMode ?
               "https://www.sandbox.paypal.com/us/cgi-bin/webscr" :
               "https://www.paypal.com/us/cgi-bin/webscr");
            string amount = this.SubTotal.ToString("N2").Replace(',', '.');
            string shipping = this.Shipping.ToString("N2").Replace(',', '.');

            string baseUrl = HttpContext.Current.Request.Url.AbsoluteUri.Replace(
               HttpContext.Current.Request.Url.PathAndQuery, "") + HttpContext.Current.Request.ApplicationPath;
            if (!baseUrl.EndsWith("/"))
                baseUrl += "/";

            string notifyUrl = HttpUtility.UrlEncode(baseUrl + "PayPal/Notify.aspx");
            string returnUrl = HttpUtility.UrlEncode(baseUrl + "PayPal/OrderCompleted.aspx?ID=" + this.Id.ToString());
            string cancelUrl = HttpUtility.UrlEncode(baseUrl + "PayPal/OrderCancelled.aspx");
            string business = HttpUtility.UrlEncode(Settings.BusinessEmail);
            string itemName = HttpUtility.UrlEncode("Order #" + this.Id.ToString());

            StringBuilder url = new StringBuilder();
            url.AppendFormat(
               "{0}?cmd=_xclick&upload=1&rm=2&no_shipping=1&no_note=1&currency_code={1}&business={2}&item_number={3}&custom={3}&item_name={4}&amount={5}&shipping={6}&notify_url={7}&return={8}&cancel_return={9}",
               serverUrl, Settings.CurrencyCode, business, this.Id, itemName,
               amount, shipping, notifyUrl, returnUrl, cancelUrl);

            return url.ToString();
        }

        /***********************************
        * Static methods
        ************************************/

        /// <summary>
        /// Returns a collection with all the order in a specified state, and within
        /// the specified range of date
        /// </summary>
        public static List<Order> GetOrders(int statusId, DateTime fromDate, DateTime toDate)
        {
            toDate = toDate.AddDays(1).Subtract(new TimeSpan(toDate.Hour, toDate.Minute, toDate.Second));
            List<Order> orders = null;
            string key = "WebShop_Orders_" + statusId + "_" + fromDate.ToShortDateString() + "_" + toDate.ToShortDateString();

            if (WebShopBase.Settings.EnableCaching && BizObject.Cache[key] != null)
            {
                orders = (List<Order>)BizObject.Cache[key];
            }
            else
            {
                orders = WebShop.GetOrders(statusId, fromDate, toDate);
                WebShopBase.CacheData(key, orders);
            }
            return orders;
        }

        /// <summary>
        /// Returns a collection with all the order for the specified customer
        /// </summary>
        public static List<Order> GetOrders(string customerName)
        {
            List<Order> orders = null;
            string key = "WebShop_Orders_" + customerName;

            if (WebShopBase.Settings.EnableCaching && BizObject.Cache[key] != null)
            {
                orders = (List<Order>)BizObject.Cache[key];
            }
            else
            {
                orders = WebShop.GetOrders(customerName);
                WebShopBase.CacheData(key, orders);
            }
            return orders;
        }

        /// <summary>
        /// Returns an Order object with the specified ID
        /// </summary>
        public static Order GetOrderById(Guid orderId)
        {
            Order order = null;
            string key = "Store_Order_" + orderId.ToString();

            if (WebShopBase.Settings.EnableCaching && BizObject.Cache[key] != null)
            {
                order = (Order)BizObject.Cache[key];
            }
            else
            {
                order = WebShop.GetOrderById(orderId);
                WebShopBase.CacheData(key, order);
            }
            return order;
        }

        /// <summary>
        /// Updates an existing order
        /// </summary>
        public static bool UpdateOrder(Guid id, int statusId, DateTime shippedDate, string transactionID, string trackingID)
        {
            using (TransactionScope scope = new TransactionScope())
            {
                transactionID = BizObject.ConvertNullToEmptyString(transactionID);
                trackingID = BizObject.ConvertNullToEmptyString(trackingID);

                // retrieve the order's current status ID
                Order order = Order.GetOrderById(id);

                // update the order
                Order record = new Order(id, DateTime.Now, "", statusId, "", "", 0.0m, 0.0m,
                   "", "", "", "", "", "", "", "", "", "", shippedDate, transactionID, trackingID, null);
                bool ret = WebShop.UpdateOrder(record);

                // if the new status ID is confirmed, than decrease the UnitsInStock for the purchased products
                if (statusId == (int)StatusCode.Confirmed && order.StatusId == (int)StatusCode.WaitingForPayment)
                {
                    foreach (OrderItem item in order.Items)
                        Product.DecrementProductUnitsInStock(item.ProductId, item.Quantity);
                }

                BizObject.PurgeCacheItems("store_order");
                scope.Complete();
                return ret;
            }
        }

        /// <summary>
        /// Deletes an existing order
        /// </summary>
        public static bool DeleteOrder(Guid id)
        {
            bool ret = WebShop.DeleteOrder(id);
            //new RecordDeletedEvent("order", id, null).Raise();
            BizObject.PurgeCacheItems("WebShop_Order");
            return ret;
        }

        /// <summary>
        /// Creates a new order
        /// </summary>
        public static Guid InsertOrder(ShoppingCart shoppingCart,
           string shippingMethod, decimal shipping, string shippingFirstName,
           string shippingLastName, string shippingStreet, string shippingPostalCode,
           string shippingCity, string shippingState, string shippingCountry,
           string customerEmail, string customerPhone, string customerFax, string transactionID)
        {
            using (TransactionScope scope = new TransactionScope())
            {
                string userName = BizObject.CurrentUserName;

                // insert the master order
                Order order = new Order(Guid.Empty, DateTime.Now,
                   userName, 1, "", shippingMethod, shoppingCart.Total, shipping,
                   shippingFirstName, shippingLastName, shippingStreet, shippingPostalCode,
                   shippingCity, shippingState, shippingCountry, customerEmail, customerPhone,
                   customerFax, DateTime.MinValue, transactionID, "", (List<OrderItem>)shoppingCart.Items);
                Guid orderId = WebShop.InsertOrder(order);

                // insert the child order items
                foreach (ShoppingCartItem item in shoppingCart.Items)
                {
                    OrderItem orderItem = new OrderItem(Guid.Empty, DateTime.Now, userName,
                       orderId, item.Id, item.Title, item.SKU, item.UnitPrice, item.Quantity);
                    WebShop.InsertOrderItem(orderItem);
                }

                BizObject.PurgeCacheItems("WebShop_Order");
                scope.Complete();

                return orderId;
            }
        }
    }
}