using System;
using System.Collections;
using System.Collections.Generic;
using System.Data;
using System.Configuration;
using System.Web;
using System.Web.Security;
using System.Web.UI;
using System.Web.UI.WebControls;
using System.Web.UI.WebControls.WebParts;
using System.Web.UI.HtmlControls;

namespace XZ.Logistics.WebShop
{
    [Serializable]
    public class ShoppingCartItem
    {
        private Guid _id = Guid.Empty;
        public Guid Id
        {
            get { return _id; }
            private set { _id = value; }
        }

        private string _title = "";
        public string Title
        {
            get { return _title; }
            private set { _title = value; }
        }

        private string _sku = "";
        public string SKU
        {
            get { return _sku; }
            private set { _sku = value; }
        }

        private decimal _unitPrice;
        public decimal UnitPrice
        {
            get { return _unitPrice; }
            private set { _unitPrice = value; }
        }

        private int _quantity = 1;
        public int Quantity
        {
            get { return _quantity; }
            set { _quantity = value; }
        }

        public ShoppingCartItem(Guid id, string title, string sku, decimal unitPrice)
        {
            this.Id = id;
            this.Title = title;
            this.SKU = sku;
            this.UnitPrice = unitPrice;
        }
    }

    [Serializable]
    public class ShoppingCart
    {
        private Dictionary<Guid, ShoppingCartItem> _items = new Dictionary<Guid, ShoppingCartItem>();
        public ICollection Items
        {
            get { return _items.Values; }
        }

        /// <summary>
        /// Gets the sum total of the items' prices
        /// </summary>
        public decimal Total
        {
            get
            {
                decimal sum = 0.0m;
                foreach (ShoppingCartItem item in _items.Values)
                    sum += item.UnitPrice * item.Quantity;
                return sum;
            }
        }

        /// <summary>
        /// Adds a new item to the shopping cart
        /// </summary>
        public void InsertItem(Guid id, string title, string sku, decimal unitPrice)
        {
            if (_items.ContainsKey(id))
                _items[id].Quantity += 1;
            else
                _items.Add(id, new ShoppingCartItem(id, title, sku, unitPrice));
        }

        /// <summary>
        /// Removes an item from the shopping cart
        /// </summary>
        public void DeleteItem(Guid id)
        {
            if (_items.ContainsKey(id))
            {
                ShoppingCartItem item = _items[id];
                item.Quantity -= 1;
                if (item.Quantity == 0)
                    _items.Remove(id);
            }
        }

        /// <summary>
        /// Removes all items of a specified product from the shopping cart
        /// </summary>
        public void DeleteProduct(Guid id)
        {
            if (_items.ContainsKey(id))
            {
                _items.Remove(id);
            }
        }

        /// <summary>
        /// Updates the quantity for an item
        /// </summary>
        public void UpdateItemQuantity(Guid id, int quantity)
        {
            if (_items.ContainsKey(id))
            {
                ShoppingCartItem item = _items[id];
                item.Quantity = quantity;
                if (item.Quantity <= 0)
                    _items.Remove(id);
            }
        }

        /// <summary>
        /// Clears the cart
        /// </summary>
        public void Clear()
        {
            _items.Clear();
        }
    }
}